summaryrefslogtreecommitdiff
path: root/src/mongo/client/authenticate.cpp
diff options
context:
space:
mode:
authorShane Harvey <shane.harvey@mongodb.com>2016-04-14 13:44:53 -0400
committerShane Harvey <shane.harvey@mongodb.com>2016-04-18 14:11:13 -0400
commit8432d0bb4809e6547338771a365f3b5340b79024 (patch)
tree2e20ba57da8e3232647e3f19ee0d57b8fdfaaa81 /src/mongo/client/authenticate.cpp
parente96fc394af9d694a86e6e5d5081bd3f9b4698bae (diff)
downloadmongo-8432d0bb4809e6547338771a365f3b5340b79024.tar.gz
SERVER-6823 Rename --tryClusterAuth to --transitionToAuth
Diffstat (limited to 'src/mongo/client/authenticate.cpp')
-rw-r--r--src/mongo/client/authenticate.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/client/authenticate.cpp b/src/mongo/client/authenticate.cpp
index 477ae40dbb9..498b37480b5 100644
--- a/src/mongo/client/authenticate.cpp
+++ b/src/mongo/client/authenticate.cpp
@@ -242,7 +242,7 @@ void authX509(RunCommandHook runCommand,
//
bool isFailedAuthOk(const AuthResponse& response) {
- return (response == ErrorCodes::AuthenticationFailed && serverGlobalParams.tryClusterAuth);
+ return (response == ErrorCodes::AuthenticationFailed && serverGlobalParams.transitionToAuth);
}
void auth(RunCommandHook runCommand,
@@ -253,8 +253,8 @@ void auth(RunCommandHook runCommand,
std::string mechanism;
auto authCompletionHandler = [handler](AuthResponse response) {
if (isFailedAuthOk(response)) {
- // If auth failed in tryClusterAuth, just pretend it succeeded.
- log() << "Failed to authenticate in tryClusterAuth, falling back to no "
+ // If auth failed in transitionToAuth, just pretend it succeeded.
+ log() << "Failed to authenticate in transitionToAuth, falling back to no "
"authentication.";
// We need to mock a successful AuthResponse.